@@ -168,15 +168,15 @@ private:
 #endif
 };
 
+
 class TestCase {
-    void Init(const char* name);
+    void Init(const std::string& name);
 
 public:
     typedef void ( TestCase ::* TestMethod ) ();
 
 protected:
-    TestCase(const std::string &name) { Init(name.c_str()); }
-    TestCase(const char* name)        { Init(name); }
+    TestCase(const std::string &name) { Init(name); }
 
 public:    
     // explicit destruction, to be used before calling exit() in out-of-process test runner
@@ -184,7 +184,7 @@ public:
 
 public:
     ncbi::NK::counter_t GetErrorCounter(void) { return _ec; }
-    const char* GetName(void) const { return _name; }
+    const char * GetName(void) const { return _name . c_str (); }
     void ErrorCounterAdd(ncbi::NK::counter_t ec) { _ec += ec; }
 
 protected:
@@ -434,10 +434,28 @@ protected:
 #define REQUIRE_NOT_NULL(e1) AssertNotNull((e1), #e1, __FILE__,__LINE__, true)
 
 private:
-    const char* _name;
+    std::string _name;
     ncbi::NK::counter_t _ec;
 };
 
+
+class SharedTest : protected TestCase {
+    TestCase * _dad;
+
+protected:
+    SharedTest ( TestCase * dad, const char * name )
+        : TestCase ( std::string ( dad -> GetName () ) + "." + name )
+        , _dad ( dad )
+    {
+        assert ( _dad );
+    }
+
+    ~SharedTest ( void ) {
+        _dad -> ErrorCounterAdd ( GetErrorCounter () );
+    }
+};
+
+
 class TestInvoker {
 protected:
     TestInvoker(const std::string& name) : _name(name), _ec(0) {}
