@@ -87,7 +87,6 @@ typedef struct CacheStatistic
     uint64_t requests_below_32k;
     uint64_t requests_consecutive;
     uint64_t requests_in_first32k;
-    
     uint64_t prev_pos;
     uint64_t requests_same_pos;
     uint64_t requests_same_pos_and_len;
@@ -190,6 +189,7 @@ typedef struct KCacheTeeFile
 #else
     uint8_t volatile * bitmap;                /* the bitmap of cached blocks */
 #endif
+
     uint64_t bitmap_bytes;                    /* how many bytes do we need to store the bitmap */
 
 #if USE_BUFFER_POOL
@@ -841,6 +841,14 @@ static void set_bitmap( const KCacheTeeFile *cself, uint64_t start_block, uint64
 }
 
 
+static rc_t switch_to_read_only( const KCacheTeeFile *cself, rc_t rc )
+{
+    KCacheTeeFile *self = ( KCacheTeeFile * )cself;
+    self->local_read_only = true;
+    LOGERR( klogInt, rc, "switching cache-tee-file to read-only" );
+    return 0;
+}
+
 static rc_t write_bitmap( const KCacheTeeFile *cself, uint64_t block )
 {
     rc_t rc;
@@ -866,8 +874,13 @@ static rc_t write_bitmap( const KCacheTeeFile *cself, uint64_t block )
 #endif
     if ( rc != 0 )
     {
+        /* it can happen that we are not able to write to the bitmap because we run out of space
+           on the local filesystem. */
+        rc = switch_to_read_only( cself, rc );
+        /*
         PLOGERR( klogErr, ( klogErr, rc, "cannot write local-file-bitmap block $(block) at $(pos) $(to_write) bytes",
                            "block=%lu,pos=%lu,to_write=%zu", block, pos, to_write ) );
+        */
     }
     return rc;
 }
@@ -928,7 +941,7 @@ static rc_t rd_remote_wr_local( const KCacheTeeFile *cself, uint64_t pos,
         size_t bytes_read;
         *num_read = 0;
         rc = KFileReadAll( cself->remote, pos, buffer, bsize, &bytes_read );
-        if ( rc != 0 || bytes_read == 0) /** try again **/
+        if ( rc != 0 || bytes_read == 0 ) /** try again **/
         {
             rc = KFileReadAll( cself->remote, pos, buffer, bsize, &bytes_read );
             if ( rc == 0 && bytes_read == 0 )
@@ -941,7 +954,13 @@ static rc_t rd_remote_wr_local( const KCacheTeeFile *cself, uint64_t pos,
             if ( cself->local_read_only )
                 *num_read = bytes_read;
             else
+            {
+                /* it can happen that we are running out of space in the local filesystem,
+                   that means we cannot write ( any more ) */
                 rc = KFileWriteAll( cself->local, pos, buffer, bytes_read, num_read );
+                if ( rc != 0 )
+                    rc = switch_to_read_only( cself, rc );
+            }
         }
     }
     return rc;
@@ -1013,55 +1032,70 @@ static rc_t KCacheTeeFileRead_simple2( const KCacheTeeFile *cself, uint64_t pos,
         else if ( IS_CACHE_BIT( cself, block ) )
         {
             uint64_t fpos = block * cself->block_size;
-            int64_t fbsize = cself -> remote_size - fpos;
-            size_t nread = 0;
-
-            if( fbsize > cself->block_size )
-                fbsize = cself -> block_size;
-
-            rc = KFileReadAll( cself->local, fpos, scratch_buffer, fbsize, &nread );
-            if ( rc == 0 )
+            if ( fpos < cself -> remote_size )
             {
-                int i;
-                uint64_t *b = ( uint64_t* )scratch_buffer;
-                first_block_in_scratch = block;
-                valid_scratch_bytes = nread;
-                
-                if ( block != salvage_block )
-                { /** check for fully space page, but don't do it in infinite loop **/
-                    for ( i = 0; i < ( nread/ sizeof( *b ) ) && b [ i]==0; i++ ) { } 
-                    if ( i == ( nread / sizeof( *b ) ) )
-                    {
-                        rc = rd_remote_wr_local( cself, block*cself->block_size, scratch_buffer, fbsize, &nread );
-                        if ( rc == 0 )
-                            salvage_block = block;
-                    }
-                    else
-                    {
-                        salvage_block = -1;
+                int64_t fbsize = cself -> remote_size - fpos;
+                size_t nread = 0;
+
+                if( fbsize > cself->block_size )
+                    fbsize = cself -> block_size;
+
+                rc = KFileReadAll( cself->local, fpos, scratch_buffer, fbsize, &nread );
+                if ( rc == 0 )
+                {
+                    int i;
+                    uint64_t *b = ( uint64_t* )scratch_buffer;
+                    first_block_in_scratch = block;
+                    valid_scratch_bytes = nread;
+                    
+                    if ( block != salvage_block )
+                    { /** check for fully space page, but don't do it in infinite loop **/
+                        for ( i = 0; i < ( nread/ sizeof( *b ) ) && b [ i]==0; i++ ) { } 
+                        if ( i == ( nread / sizeof( *b ) ) )
+                        {
+                            rc = rd_remote_wr_local( cself, block*cself->block_size, scratch_buffer, fbsize, &nread );
+                            if ( rc == 0 )
+                                salvage_block = block;
+                        }
+                        else
+                        {
+                            salvage_block = -1;
+                        }
                     }
                 }
             }
+            else
+            {
+                to_read_total = 0;
+            }
         }
         else
         {
             uint64_t fpos = block * cself->block_size;
-            int64_t  fbsize = cself->remote_size - fpos;
-            size_t   nread = 0;
-
-            if ( fbsize > cself->block_size )
-                fbsize = cself->block_size;
-            rc = rd_remote_wr_local( cself, fpos, scratch_buffer, fbsize, &nread );
-            if ( rc == 0 )
+            if ( fpos < cself -> remote_size )
             {
-                first_block_in_scratch = block;
-                valid_scratch_bytes = nread;
-                if ( !cself->local_read_only )
+                int64_t fbsize = cself->remote_size - fpos;
+                size_t  nread = 0;
+
+                if ( fbsize > cself->block_size )
+                    fbsize = cself->block_size;
+
+                rc = rd_remote_wr_local( cself, fpos, scratch_buffer, fbsize, &nread );
+                if ( rc == 0 )
                 {
-                    set_bitmap( cself, block, 1 );
-                    rc = write_bitmap( cself, block );
+                    first_block_in_scratch = block;
+                    valid_scratch_bytes = nread;
+                    if ( !cself->local_read_only )
+                    {
+                        set_bitmap( cself, block, 1 );
+                        rc = write_bitmap( cself, block );
+                    }
                 }
             }
+            else
+            {
+                to_read_total = 0;
+            }
         }
 
     }
@@ -1311,6 +1345,13 @@ static KFile_vt_v1 vtKCacheTeeFile =
     /* end minor version 0 methods */
 };
 
+static rc_t hand_out_remote_file_as_tee_file( struct KFile const **tee, struct KFile const *remote )
+{
+    rc_t rc = KFileAddRef( remote );
+    if ( rc == 0 )
+        *tee = remote;
+    return rc;
+}
 
 static rc_t make_cache_tee( struct KDirectory *self, struct KFile const **tee,
     struct KFile const *remote, struct KFile *local, uint32_t blocksize, bool read_only, const char *path )
@@ -1447,11 +1488,13 @@ static rc_t make_cache_tee( struct KDirectory *self, struct KFile const **tee,
             }
         }
         free ( cf );
+        /* if we arrived here, we do not have enough space on the local filesystem */
+        rc = hand_out_remote_file_as_tee_file( tee, remote );
+        LOGERR( klogInt, rc, "skipping the cache-tee completely" );
     }
     return rc;
 }
 
-
 static rc_t make_read_only_cache_tee( struct KDirectory *self,
     struct KFile const **tee, struct KFile const *remote, uint32_t blocksize, const char *path )
 {
@@ -1459,14 +1502,6 @@ static rc_t make_read_only_cache_tee( struct KDirectory *self,
     rc_t rc = KDirectoryOpenFileRead( self, &local, "%s.cache", path );
     if ( rc == 0 )
         rc = make_cache_tee( self, tee, remote, ( struct KFile * )local, blocksize, true, path );
-    else
-    {
-        /* we cannot even open the local cache in read-only mode,
-           we give up - and return a reference to the remote file... */
-        rc = KFileAddRef( remote );
-        if ( rc == 0 )
-            *tee = remote;
-    }
     return rc;
 }
 
