@@ -71,6 +71,7 @@ struct KSysDirListing;
 #include <dirent.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/statvfs.h> /* statvfs */
 #include <utime.h>
 #include <assert.h>
 
@@ -452,7 +453,7 @@ rc_t KSysDirMakePath_v1 ( const KSysDir_v1 * self, enum RCContext ctx, bool cano
                 return RC ( rcFS, rcDirectory, ctx, rcPath, rcExcessive );
             memmove ( buffer + bsize, buffer, psize + 1 );
             assert ( self -> path [ bsize - 1 ] == '/' );
-            memcpy ( buffer, self -> path, bsize );
+            memmove ( buffer, self -> path, bsize );
         }
         else if ( ( bsize = self -> root ) != 0 )
         {
@@ -460,7 +461,7 @@ rc_t KSysDirMakePath_v1 ( const KSysDir_v1 * self, enum RCContext ctx, bool cano
                 return RC ( rcFS, rcDirectory, ctx, rcPath, rcExcessive );
             memmove ( buffer + bsize, buffer, psize + 1 );
             assert ( self -> path [ bsize - 1 ] != '/' );
-            memcpy ( buffer, self -> path, bsize );
+            memmove ( buffer, self -> path, bsize );
         }
     }
     else
@@ -468,12 +469,12 @@ rc_t KSysDirMakePath_v1 ( const KSysDir_v1 * self, enum RCContext ctx, bool cano
         if ( path [ 0 ] != '/' )
         {
             assert ( self -> path [ self -> size - 1 ] == '/' );
-            memcpy ( buffer, self -> path, bsize = self -> size );
+            memmove ( buffer, self -> path, bsize = self -> size );
         }
         else if ( ( bsize = self -> root ) != 0 )
         {
             assert ( self -> path [ bsize - 1 ] != '/' );
-            memcpy ( buffer, self -> path, bsize );
+            memmove ( buffer, self -> path, bsize );
         }
 
         if ( args == NULL )
@@ -819,7 +820,7 @@ rc_t KSysDirRelativePath_v1 ( const KSysDir_v1 * self, enum RCContext ctx,
 
     /* insert backup sequences */
     for ( bsize = 0; backup > 0; bsize += 3, -- backup )
-        memcpy ( & path [ bsize ], "../", 3 );
+        memmove ( & path [ bsize ], "../", 3 );
 
     /* close gap */
     if ( p - path > bsize )
@@ -2345,7 +2346,7 @@ rc_t KSysDirInit_v1 ( KSysDir_v1 * self, enum RCContext ctx, uint32_t dad_root,
         return ResetRCContext ( rc, rcFS, rcDirectory, ctx );
 
     if ( path != NULL )
-        memcpy ( self -> path, path, path_size );
+        memmove ( self -> path, path, path_size );
     self -> root = chroot ? path_size : dad_root;
     self -> size = path_size + 1;
     self -> path [ path_size ] = '/';
@@ -2412,3 +2413,26 @@ LIB_EXPORT rc_t CC KDirectoryNativeDir_v1 ( KDirectory_v1 **dirp )
 
     return rc;
 }
+
+LIB_EXPORT rc_t CC KDirectoryGetDiskFreeSpace_v1 ( const KDirectory * self,
+    uint64_t * free_bytes_available, uint64_t * total_number_of_bytes )
+{
+    if ( self == NULL )
+        return RC ( rcFS, rcDirectory, rcAccessing, rcSelf, rcNull );
+    else {
+        KSysDir_v1 * dir = ( KSysDir_v1 * ) self;
+        struct statvfs buf;
+        memset ( & buf, 0, sizeof buf );
+        if ( statvfs ( dir -> path, & buf) == 0 ) {
+            if ( free_bytes_available != NULL ) {
+                * free_bytes_available  = buf . f_bavail * buf . f_frsize;
+            }
+            if ( total_number_of_bytes != NULL ) {
+                * total_number_of_bytes = buf . f_blocks * buf . f_frsize;
+            }
+            return 0;
+        }
+
+        return RC ( rcFS, rcDirectory, rcAccessing, rcError, rcUnknown );
+    }
+}
