@@ -353,10 +353,8 @@ rc_t logsubstituteparams ( const char* msg, uint32_t argc, const wrt_nvp_t argv[
                 }
             }
             /* substitute param value */
-            for(value = arg->value; *value != 0; value++, sz++) {
-                if( sz < bsize ) {
+            for(value = arg->value; *value != 0 && sz < bsize; value++, sz++) {
                     buffer[sz] = *value;
-                }
             }
             /* compensate for outer loop's increment */
             --sz;
@@ -469,7 +467,24 @@ static
 rc_t prep_v_args( uint32_t* argc, wrt_nvp_t argv[], size_t max_argc,
                   char* pbuffer, size_t pbsize, const char* fmt, va_list args )
 {
-    rc_t rc = string_vprintf ( pbuffer, pbsize, NULL, fmt, args );
+    size_t num_writ = 0;
+    rc_t rc = string_vprintf ( pbuffer, pbsize, & num_writ, fmt, args );
+    if ( rc == SILENT_RC ( rcText, rcString, rcConverting, rcBuffer,
+                           rcInsufficient ) )
+    {
+        size_t pos = num_writ;
+        char truncated [] = "... [ truncated ]";
+        size_t required = num_writ + sizeof truncated;
+        if ( required > pbsize ) {
+            assert ( pbsize > sizeof truncated );
+            pos = pbsize - sizeof truncated;
+        }
+        {
+            size_t c = string_copy_measure ( pbuffer + pos, pbsize, truncated );
+            assert ( c + 1 == sizeof truncated );
+            rc = 0;
+        }
+    }
     if ( rc == 0 )
     {
         /* tokenize the parameters into name/value pairs */
@@ -625,6 +640,7 @@ rc_t log_print( KFmtHandler* formatter, const KLogFmtFlags flags, KWrtHandler* w
             rc = prep_v_args(&argc, argv, sizeof(argv)/sizeof(argv[0]) - 1, pbuffer, sizeof(pbuffer), fmt, args);
         }
         if( rc == 0 && (flags & klogFmtMessage) ) {
+            int retries = 0;
             if( msg == NULL || msg[0] == '\0' ) {
                 msg = "empty log message";
             }
@@ -649,7 +665,9 @@ rc_t log_print( KFmtHandler* formatter, const KLogFmtFlags flags, KWrtHandler* w
                     }
                     break;
                 }
-            } while(rc == 0);
+                if ( retries ++ > 9 ) /* something is wrong: too many retries */
+                    break;
+            } while(rc != 0);
         }
     }
     if( rc != 0 ) {
