@@ -106,6 +106,8 @@ struct KSocket
         struct sockaddr_in6 v6;     /* for ipv6 */
     } remote_addr;
     bool remote_addr_valid;
+
+    char ip_address [ 256 ];
 };
 
 LIB_EXPORT rc_t CC KSocketAddRef( const KSocket *self )
@@ -415,6 +417,8 @@ static rc_t KSocketGetEndpoint ( const KSocket * self, KEndPoint * ep, bool remo
         rc = RC ( rcNS, rcSocket, rcEvaluating, rcParam, rcNull );
     else
     {
+        memset ( ep, 0, sizeof * ep );
+
         ep -> type = epInvalid;
 
         if ( self == NULL )
@@ -433,6 +437,9 @@ static rc_t KSocketGetEndpoint ( const KSocket * self, KEndPoint * ep, bool remo
                 rc = RC ( rcNS, rcSocket, rcEvaluating, rcFunction, rcUnsupported );
                 break;
             }
+
+            string_copy_measure ( ep -> ip_address, sizeof ep -> ip_address,
+                                  self -> ip_address );
         }
     }
     return rc;
@@ -871,6 +878,10 @@ rc_t KSocketConnectIPv4 ( KSocket *self, const KEndPoint *from, const KEndPoint
                 /* set non-blocking mode */
                 flag = fcntl ( self -> fd, F_GETFL );
                 fcntl ( self -> fd, F_SETFL, flag | O_NONBLOCK );
+
+                string_copy_measure ( self -> ip_address,
+                    sizeof self -> ip_address, to -> ip_address );
+
                 return 0;
             }
         }
