@@ -478,6 +478,7 @@ void KEncFileFooterSwap (const KEncFile * self, KEncFileFooter * foot)
  * Read
  * If we know where the footer is we can read it specifically
  */
+#if 0
 static
 rc_t KEncFileFooterRead (KEncFile * self, const uint64_t pos,
                          const bool validate)
@@ -526,7 +527,7 @@ rc_t KEncFileFooterRead (KEncFile * self, const uint64_t pos,
 
     return rc;
 }
-
+#endif
 
 /* ----------
  * Write
@@ -549,7 +550,7 @@ rc_t KEncFileFooterWrite (KEncFile * self)
     }
     else
     {
-        memcpy ( & foot, & self -> foot, sizeof foot );
+        memmove ( & foot, & self -> foot, sizeof foot );
     }
 
     KEncFileFooterSwap (self, &foot);
@@ -1078,7 +1079,7 @@ rc_t KEncFileBlockRead (KEncFile * self, KEncFileBlock * block,
                         rc = RC (rcKrypto, rcFile, rcReading, rcData, rcIncomplete);
                     else
                     {
-                        memcpy (block, &u.b, sizeof u.b);
+                        memmove (block, &u.b, sizeof u.b);
                         rc = 0;
                     }
                 }
@@ -2542,7 +2543,7 @@ LIB_EXPORT rc_t CC KFileIsEnc_v2 (const char * buffer, size_t buffer_size)
     
     count = buffer_size > sizeof header ? sizeof header : buffer_size;
 
-    memcpy (&header, buffer, count);
+    memmove (&header, buffer, count);
 
     if (header.byte_order == const_header.byte_order)
         byte_swapped = false;
@@ -2591,7 +2592,7 @@ LIB_EXPORT rc_t CC KFileIsSraEnc (const char * buffer, size_t buffer_size)
     
     count = buffer_size > sizeof header ? sizeof header : buffer_size;
 
-    memcpy (&header, buffer, count);
+    memmove (&header, buffer, count);
 
     if (header.byte_order == const_header.byte_order)
         byte_swapped = false;
