@@ -131,8 +131,9 @@ public:
         file=0;
     }
 
-    void CreateAndLoad(const char* name, const char* contents)
+    void CreateAndLoad(const string & sname, const char* contents)
     {
+        const char * name = sname . c_str ();
 #ifdef DBG_KFG
         cout << "26 CreateAndLoad(" << name << ")\n";
 #endif
