@@ -32,6 +32,7 @@
 
 #include <ktst/unit_test.hpp>
 
+#include <klib/debug.h> /* KDbgSetString */
 #include <klib/log.h>
 #include <klib/rc.h>
 #include <kfg/config.h>
@@ -109,13 +110,13 @@ public:
         
         if ( response.size() >= bsize )
         {
-            memcpy(buffer, response.c_str(), bsize);
+            memmove(buffer, response.c_str(), bsize);
             * num_read = bsize; 
             response = response.substr(bsize);
         }
         else
         {
-            memcpy(buffer, response.c_str(), response.size());
+            memmove(buffer, response.c_str(), response.size());
             * num_read = response.size();
             response.clear();
         }
@@ -794,8 +795,10 @@ TEST_CASE(ContentLength) {
 
     /* calling good cgi returns 200 and resolved path */
     REQUIRE_RC ( KNSManagerMakeReliableClientRequest ( kns, & req, 0x01000000,
-        NULL, "http://www.ncbi.nlm.nih.gov/Traces/names/names.cgi" ) ); 
+        NULL, "https://www.ncbi.nlm.nih.gov/Traces/names/names.cgi" ) ); 
     REQUIRE_RC ( KHttpRequestAddPostParam ( req, "acc=AAAB01" ) );
+    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "accept-proto=https" ) );
+    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "version=1.2" ) );
     REQUIRE_RC ( KHttpRequestPOST ( req, & rslt ) );
     REQUIRE_RC ( KClientHttpResultStatus ( rslt, & code, NULL, 0, NULL ) );
     REQUIRE_EQ ( code, 200u );
@@ -812,7 +815,7 @@ TEST_CASE(ContentLength) {
 
     /* calling non-existing cgi returns 404 */
     REQUIRE_RC ( KNSManagerMakeReliableClientRequest ( kns, & req, 0x01000000,
-        NULL, "http://www.ncbi.nlm.nih.gov/Traces/names/bad.cgi" ) ); 
+        NULL, "https://www.ncbi.nlm.nih.gov/Traces/names/bad.cgi" ) ); 
     REQUIRE_RC ( KHttpRequestAddPostParam ( req, "acc=AAAB01" ) );
     REQUIRE_RC ( KHttpRequestPOST ( req, & rslt ) );
     REQUIRE_RC ( KClientHttpResultStatus ( rslt, & code, NULL, 0, NULL ) );
@@ -857,6 +860,8 @@ const char UsageDefaultName[] = "test-http";
 
 rc_t CC KMain ( int argc, char *argv [] )
 {
+    if ( 0 ) assert ( ! KDbgSetString ( "VFS" ) );
+
     KConfigDisableUserSettings();
 
 	// this makes messages from the test code appear
