@@ -35,6 +35,8 @@
 
 #include <klib/printf.h>
 
+#include <kproc/timeout.h>
+
 #include <kns/manager.h>
 #include <kns/endpoint.h>
 #include <kns/stream.h>
@@ -44,6 +46,8 @@
 #include <kfs/directory.h>
 #include <kfs/file.h>
 
+#include <kapp/args.h> /* ArgsMakeAndHandle */
+
 #include <kproc/thread.h>
 #include <kproc/timeout.h>
 
@@ -55,7 +59,8 @@
 #include <algorithm>
 #include <sstream>
 
-TEST_SUITE(KnsTestSuite);
+static rc_t argsHandler(int argc, char* argv[]);
+TEST_SUITE_WITH_ARGS_HANDLER(KnsTestSuite, argsHandler);
 
 using namespace std;
 using namespace ncbi::NK;
@@ -179,8 +184,10 @@ FIXTURE_TEST_CASE(MakeIPCConnection_NoListener, KnsManagerFixture)
 {
     CONST_STRING(&name, "socket");
     REQUIRE_RC(KNSManagerInitIPCEndpoint(mgr, &ep, &name));
+    timeout_t tm;
+    TimeoutInit ( & tm, 0 );
     KSocket* socket;
-    REQUIRE_RC_FAIL(KNSManagerMakeRetryConnection(mgr, &socket, 0, NULL, &ep)); /* no server; no retries */
+    REQUIRE_RC_FAIL(KNSManagerMakeRetryConnection(mgr, &socket, &tm, NULL, &ep)); /* no server; no retries */
     REQUIRE_NULL(socket);
 }   
 
@@ -349,8 +356,11 @@ public:
     
     KStream* MakeStream( int32_t p_retryTimeout )
     {
+        timeout_t tm;
+        TimeoutInit ( & tm, p_retryTimeout );
+
         KSocket* socket;
-        THROW_ON_RC ( KNSManagerMakeRetryConnection(mgr, &socket, p_retryTimeout, NULL, &ep) );
+        THROW_ON_RC ( KNSManagerMakeRetryConnection(mgr, &socket, &tm, NULL, &ep) );
         if (socket == 0)
            throw logic_error ( "MakeStream: KStreamRelease failed" );
            
@@ -380,7 +390,7 @@ PROCESS_FIXTURE_TEST_CASE(IPCEndpoint_Basic, SocketFixture, 0, 5)
 {   // client runs in a child process
     string content = GetName();
     
-    KStream* stream = MakeStream ( 50 ); /* this might make some retries while the server is setting up */
+    KStream* stream = MakeStream ( 50 * 1000 ); /* this might make some retries while the server is setting up */
     LOG(LogLevel::e_message, "client '" << GetName() << "' after KNSMakeConnection" << endl);    
     
     REQUIRE_RC(KStreamWrite(stream, content.c_str(), content.length(), &num));
@@ -397,12 +407,12 @@ PROCESS_FIXTURE_TEST_CASE(IPCEndpoint_Basic, SocketFixture, 0, 5)
 PROCESS_FIXTURE_TEST_CASE(IPCEndpoint_MultipleListeners, SocketFixture, 0, 100) 
 {   // client runs in a child process
     
-    KStream* stream = MakeStream ( 50 ); /* this might make some retries while the server is setting up */
+    KStream* stream = MakeStream ( 50 * 1000 ); /* this might make some retries while the server is setting up */
     LOG(LogLevel::e_message, "client '" << GetName() << "' after KNSMakeConnection1" << endl);    
 
     TestEnv::Sleep(1); // on Windows 32, when the two calls to KNSManagerMakeConnection follow too closely, sometimes things get messed up
     
-    KStream* stream2 = MakeStream ( 5 ); /* should work from the first try now*/
+    KStream* stream2 = MakeStream ( 5 * 1000 ); /* should work from the first try now*/
     LOG(LogLevel::e_message, "client '" << GetName() << "' after KNSMakeConnection2" << endl);    
     
     string content = string(GetName())+"_1";
@@ -431,7 +441,7 @@ PROCESS_FIXTURE_TEST_CASE(IPCEndpoint_ReadAll, SocketFixture, 0, 5)
 {   // call ReadAll requesting more bytes than available, see it return only what is available
     string content = GetName();
     
-    KStream* stream = MakeStream ( 5 ); 
+    KStream* stream = MakeStream ( 5 * 1000 );
     LOG(LogLevel::e_message, "client '" << GetName() << "' after KNSMakeConnection" << endl);    
     
     REQUIRE_RC(KStreamWrite(stream, content.c_str(), content.length(), &num));
@@ -477,7 +487,7 @@ public:
         if (KNSManagerInitIPCEndpoint(mgr, &ep, &name) != 0)
 			throw logic_error ( string("TimedReadSocketFixture: SetupClient(") + p_content + "), KNSManagerInitIPCEndpoint failed" );
 
-        m_stream = MakeStream ( 5 ); 
+        m_stream = MakeStream ( 5 * 1000 );
         LOG(LogLevel::e_message, "client '" << p_content << "' after KNSMakeConnection" << endl);    
 	}
 	void SetupClient(const string& p_content, uint32_t p_timeoutMs)
@@ -624,14 +634,17 @@ public:
         if (KNSManagerInitIPCEndpoint(mgr, &ep, &name) != 0)
 			throw logic_error ( string("TimedConnection_ReadSocketFixture: SetupClient(") + p_content + "), KNSManagerInitIPCEndpoint failed" );
     
-        m_stream = MakeStreamTimed( 5, p_readMillis, p_writeMillis );
+        m_stream = MakeStreamTimed( 5 * 1000, p_readMillis, p_writeMillis );
         LOG(LogLevel::e_message, "client '" << p_content << "' after KNSMakeConnection" << endl);    
 	}
 
     KStream* MakeStreamTimed( int32_t p_retryTimeout, int32_t p_readMillis, int32_t p_writeMillis  )
     {
+        timeout_t tm;
+        TimeoutInit ( & tm, p_retryTimeout );
+
         KSocket* socket;
-        THROW_ON_RC ( KNSManagerMakeRetryTimedConnection(mgr, &socket, p_retryTimeout, p_readMillis, p_writeMillis, NULL, &ep) );
+        THROW_ON_RC ( KNSManagerMakeRetryTimedConnection(mgr, &socket, &tm, p_readMillis, p_writeMillis, NULL, &ep) );
         if (socket == 0)
            throw logic_error ( "MakeStreamTimed: KStreamRelease failed" );
            
@@ -716,7 +729,7 @@ PROCESS_FIXTURE_TEST_CASE(TimedConnection_ReadOverride_0_Timeout, TimedConnectio
 }
 PROCESS_FIXTURE_TEST_CASE(TimedConnection_SettingsOverride_0_Timeout, TimedConnection_ReadSocketFixture, 0, 20)
 {   // 2.2.2 time out immediately when the server has not yet responded
-    REQUIRE_RC(KNSManagerSetConnectionTimeouts(mgr, 5, 0, 0)); // override default setting (long time-out) to "no wait"
+    REQUIRE_RC(KNSManagerSetConnectionTimeouts(mgr, 5000, 0, 0)); // override default setting (long time-out) to "no wait"
     string content = GetName();
 	TimedReadSocketFixture::SetupClient(content); 
 
@@ -829,8 +842,8 @@ public:
         if (KNSManagerInitIPCEndpoint(mgr, &ep, &name) != 0)
 			throw logic_error ( string("TimedWriteSocketFixture: SetupClient(") + p_name + "), KNSManagerInitIPCEndpoint failed" );
     
-        m_data = MakeStream ( 5 );
-        m_control = MakeStream ( 5 );
+        m_data = MakeStream ( 5 * 1000 );
+        m_control = MakeStream ( 5 * 1000 );
 			
 		// identify data/control channels to the server
 		WriteMessage(m_data, "data");
@@ -1034,6 +1047,14 @@ PROCESS_FIXTURE_TEST_CASE(TimedWrite_NULL_Timeout, TimedWriteSocketFixture, 0, 2
 //  TODO: KStreamWriteExactly, KStreamTimedWriteExactly
 
 //////////////////////////////////////////// Main
+
+static rc_t argsHandler(int argc, char * argv[]) {
+    Args * args = NULL;
+    rc_t rc = ArgsMakeAndHandle(&args, argc, argv, 0, NULL, 0);
+    ArgsWhack(args);
+    return rc;
+}
+
 extern "C"
 {
 
