@@ -53,29 +53,53 @@ class WVDB_Fixture
 {
 public:
     WVDB_Fixture()
+    : m_db ( 0 )
     {
-        THROW_ON_RC ( KDirectoryNativeDir ( & m_wd ) );
-        THROW_ON_RC ( VDBManagerMakeUpdate ( & m_mgr, m_wd ) );
     }
     ~WVDB_Fixture()
     {
-        VDBManagerRelease ( m_mgr );
+        if ( m_db )
+        {
+            VDatabaseRelease ( m_db );
+        }
         RemoveDatabase();
-        KDirectoryRelease ( m_wd );
     }
-    void RemoveDatabase()
+
+    void RemoveDatabase ()
     {
         if ( ! m_databaseName . empty () )
         {
-            KDirectoryRemove ( m_wd, true, m_databaseName . c_str () );
+            KDirectory* wd;
+            KDirectoryNativeDir ( & wd );
+            KDirectoryRemove ( wd, true, m_databaseName . c_str () );
+            KDirectoryRelease ( wd );
         }
     }
 
-    KDirectory* m_wd;
-    VDBManager* m_mgr;
-    string m_databaseName;
-};
+    void MakeDatabase ( const string& p_schemaText, const string& p_schemaSpec )
+    {
+        RemoveDatabase();
 
+        VDBManager* mgr;
+        THROW_ON_RC ( VDBManagerMakeUpdate ( & mgr, NULL ) );
+        VSchema* schema;
+        THROW_ON_RC ( VDBManagerMakeSchema ( mgr, & schema ) );
+        THROW_ON_RC ( VSchemaParseText(schema, NULL, p_schemaText . c_str(), p_schemaText . size () ) );
+
+        THROW_ON_RC ( VDBManagerCreateDB ( mgr,
+                                          & m_db,
+                                          schema,
+                                          p_schemaSpec . c_str (),
+                                          kcmInit + kcmMD5,
+                                          "%s",
+                                          m_databaseName . c_str () ) );
+        THROW_ON_RC ( VSchemaRelease ( schema ) );
+        THROW_ON_RC ( VDBManagerRelease ( mgr ) );
+    }
+
+    string m_databaseName;
+    VDatabase* m_db;
+};
 
 // this test case is not very useful but is here as a blueprint for other write-side tests
 FIXTURE_TEST_CASE ( BlobCorruptOnCommit, WVDB_Fixture)
@@ -107,32 +131,13 @@ FIXTURE_TEST_CASE ( BlobCorruptOnCommit, WVDB_Fixture)
 "};\n"
 ;
     const char * schemaSpec = "db";
-
-    // MakeDatabase
-    VDatabase* db;
-    {
-        VDBManager* mgr;
-        REQUIRE_RC ( VDBManagerMakeUpdate ( & mgr, NULL ) );
-        VSchema* schema;
-        REQUIRE_RC ( VDBManagerMakeSchema ( mgr, & schema ) );
-        REQUIRE_RC ( VSchemaParseText(schema, NULL, schemaText . c_str(), schemaText . size () ) );
-
-        REQUIRE_RC ( VDBManagerCreateDB ( mgr,
-                                          & db,
-                                          schema,
-                                          schemaSpec,
-                                          kcmInit + kcmMD5,
-                                          "%s",
-                                          m_databaseName . c_str () ) );
-        REQUIRE_RC ( VSchemaRelease ( schema ) );
-        REQUIRE_RC ( VDBManagerRelease ( mgr ) );
-    }
+    MakeDatabase ( schemaText, schemaSpec );
 
     // MakeCursor
     VCursor* cursor;
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseCreateTable ( db, & table, "REFERENCE", kcmCreate | kcmMD5, "%s", "REFERENCE" ) );
+        REQUIRE_RC ( VDatabaseCreateTable ( m_db, & table, "REFERENCE", kcmCreate | kcmMD5, "%s", "REFERENCE" ) );
         REQUIRE_RC ( VTableCreateCursorWrite ( table, & cursor, kcmInsert ) );
         REQUIRE_RC ( VTableRelease ( table ) );
     }
@@ -159,8 +164,6 @@ FIXTURE_TEST_CASE ( BlobCorruptOnCommit, WVDB_Fixture)
     REQUIRE_RC ( VCursorCommit ( cursor ) );    // this returns rcVDB,rcBlob,rcValidating,rcBlob,rcCorrupt if the schema does not support
                                                 // writing to the LABEL column from the code
     REQUIRE_RC ( VCursorRelease ( cursor ) );
-
-    REQUIRE_RC ( VDatabaseRelease ( db ) );
 }
 
 FIXTURE_TEST_CASE ( ColumnOpenMetadata, WVDB_Fixture )
@@ -174,22 +177,11 @@ FIXTURE_TEST_CASE ( ColumnOpenMetadata, WVDB_Fixture )
     const char* TableName = "TABLE1";
     const char* ColumnName = "column1";
 
-    VDatabase* db;
+    MakeDatabase ( schemaText, "root_database" );
+
     {
-        VSchema* schema;
-        REQUIRE_RC ( VDBManagerMakeSchema ( m_mgr, & schema ) );
-        REQUIRE_RC ( VSchemaParseText ( schema, NULL, schemaText . c_str (), schemaText . size () ) );
-
-        REQUIRE_RC ( VDBManagerCreateDB ( m_mgr,
-                                          & db,
-                                          schema,
-                                          "root_database",
-                                          kcmInit + kcmMD5,
-                                          "%s",
-                                          m_databaseName . c_str () ) );
-
         VTable* table;
-        REQUIRE_RC ( VDatabaseCreateTable ( db , & table, TableName, kcmInit + kcmMD5, TableName ) );
+        REQUIRE_RC ( VDatabaseCreateTable ( m_db , & table, TableName, kcmInit + kcmMD5, TableName ) );
 
         VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorWrite ( table, & cursor, kcmInsert ) );
@@ -212,12 +204,11 @@ FIXTURE_TEST_CASE ( ColumnOpenMetadata, WVDB_Fixture )
 
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VSchemaRelease ( schema ) );
     }
     // update the column's metadata without re-opening the database
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableUpdate ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableUpdate ( m_db , & table, TableName ) );
         KTable* ktbl;
         REQUIRE_RC ( VTableOpenKTableUpdate ( table, & ktbl ) );
         KColumn* col;
@@ -237,7 +228,6 @@ FIXTURE_TEST_CASE ( ColumnOpenMetadata, WVDB_Fixture )
         REQUIRE_RC ( KColumnRelease ( col ) );
         REQUIRE_RC ( KTableRelease ( ktbl ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VDatabaseRelease ( db ) );
     }
 }
 
@@ -253,22 +243,10 @@ FIXTURE_TEST_CASE ( VTableDropColumn_PhysicalColumn, WVDB_Fixture )
     const char* ColumnName1 = "column1";
     const char* ColumnName2 = "column2";
 
-    VDatabase* db;
+    MakeDatabase ( schemaText, "root_database" );
     {
-        VSchema* schema;
-        REQUIRE_RC ( VDBManagerMakeSchema ( m_mgr, & schema ) );
-        REQUIRE_RC ( VSchemaParseText ( schema, NULL, schemaText . c_str (), schemaText . size () ) );
-
-        REQUIRE_RC ( VDBManagerCreateDB ( m_mgr,
-                                          & db,
-                                          schema,
-                                          "root_database",
-                                          kcmInit + kcmMD5,
-                                          "%s",
-                                          m_databaseName . c_str () ) );
-
         VTable* table;
-        REQUIRE_RC ( VDatabaseCreateTable ( db , & table, TableName, kcmInit + kcmMD5, TableName ) );
+        REQUIRE_RC ( VDatabaseCreateTable ( m_db , & table, TableName, kcmInit + kcmMD5, TableName ) );
 
         VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorWrite ( table, & cursor, kcmInsert ) );
@@ -295,19 +273,18 @@ FIXTURE_TEST_CASE ( VTableDropColumn_PhysicalColumn, WVDB_Fixture )
 
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VSchemaRelease ( schema ) );
     }
     // drop column1
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableUpdate ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableUpdate ( m_db , & table, TableName ) );
         REQUIRE_RC ( VTableDropColumn ( table, ColumnName1 ) );
         REQUIRE_RC ( VTableRelease ( table ) );
     }
     // finally, check resulted db
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableUpdate ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableUpdate ( m_db , & table, TableName ) );
         const VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorRead ( (const VTable*) table, & cursor ) );
         uint32_t column_idx1;
@@ -323,7 +300,51 @@ FIXTURE_TEST_CASE ( VTableDropColumn_PhysicalColumn, WVDB_Fixture )
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
     }
-    REQUIRE_RC ( VDatabaseRelease ( db ) );
+}
+
+FIXTURE_TEST_CASE ( CreateTableInNestedDatabase, WVDB_Fixture )
+{   // VDB-1617: VDatabaseOpenTableRead inside a nested database segfaults
+    m_databaseName = ScratchDir + GetName();
+    string schemaText =
+        "table table1 #1.0.0 { column ascii column1; };"
+        "database database0 #1 { table table1 #1 TABLE1; } ;"
+        "database db #1 { database database0 #1 SUBDB; } ;" ;
+
+    // Create the database and the table
+    MakeDatabase ( schemaText, "db" );
+    {   // make nested database and a table in it
+        VDatabase* subdb;
+        REQUIRE_RC ( VDatabaseCreateDB ( m_db, & subdb, "SUBDB", kcmInit + kcmMD5, "SUBDB" ) );
+
+        VTable *tbl;
+        REQUIRE_RC ( VDatabaseCreateTable ( subdb, & tbl, "TABLE1", kcmInit + kcmMD5, "TABLE1" ) );
+
+        REQUIRE_RC ( VTableRelease ( tbl ) );
+        REQUIRE_RC ( VDatabaseRelease ( subdb ) );
+    }
+    REQUIRE_RC ( VDatabaseRelease ( m_db ) );
+
+    // Re-open the database, try to open the table
+    {
+        VDBManager * mgr;
+        VDatabase  * subdb;
+        const VTable * tbl;
+
+        REQUIRE_RC ( VDBManagerMakeUpdate ( & mgr, NULL ) );
+        REQUIRE_RC ( VDBManagerOpenDBUpdate ( mgr,
+                                              & m_db,
+                                              NULL,
+                                              "%s",
+                                              m_databaseName . c_str () ) );
+        REQUIRE_RC ( VDatabaseOpenDBUpdate ( m_db, & subdb, "SUBDB" ) );
+
+        // open the nested database and a table in it
+        REQUIRE_RC ( VDatabaseOpenTableRead ( subdb, & tbl, "%s", "TABLE1" ) ); // segfault no more...
+        REQUIRE_RC ( VTableRelease ( tbl ) );
+
+        REQUIRE_RC ( VDatabaseRelease ( subdb ) );
+        REQUIRE_RC ( VDBManagerRelease ( mgr ) );
+    }
 }
 
 FIXTURE_TEST_CASE ( VTableDropColumn_MetadataColumn_VDB_2735, WVDB_Fixture )
@@ -338,22 +359,10 @@ FIXTURE_TEST_CASE ( VTableDropColumn_MetadataColumn_VDB_2735, WVDB_Fixture )
     const char* ColumnName1 = "column1";
     const char* ColumnName2 = "column2";
 
-    VDatabase* db;
+    MakeDatabase ( schemaText, "root_database" );
     {
-        VSchema* schema;
-        REQUIRE_RC ( VDBManagerMakeSchema ( m_mgr, & schema ) );
-        REQUIRE_RC ( VSchemaParseText ( schema, NULL, schemaText . c_str (), schemaText . size () ) );
-
-        REQUIRE_RC ( VDBManagerCreateDB ( m_mgr,
-                                          & db,
-                                          schema,
-                                          "root_database",
-                                          kcmInit + kcmMD5,
-                                          "%s",
-                                          m_databaseName . c_str () ) );
-
         VTable* table;
-        REQUIRE_RC ( VDatabaseCreateTable ( db , & table, TableName, kcmInit + kcmMD5, TableName ) );
+        REQUIRE_RC ( VDatabaseCreateTable ( m_db , & table, TableName, kcmInit + kcmMD5, TableName ) );
 
         VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorWrite ( table, & cursor, kcmInsert ) );
@@ -380,19 +389,18 @@ FIXTURE_TEST_CASE ( VTableDropColumn_MetadataColumn_VDB_2735, WVDB_Fixture )
 
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VSchemaRelease ( schema ) );
     }
     // drop column1
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableUpdate ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableUpdate (m_db , & table, TableName ) );
         REQUIRE_RC ( VTableDropColumn ( table, ColumnName1 ) );
         REQUIRE_RC ( VTableRelease ( table ) );
     }
     // finally, check resulted db
     {
         VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableUpdate ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableUpdate ( m_db , & table, TableName ) );
         const VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorRead ( (const VTable*) table, & cursor ) );
         uint32_t column_idx1;
@@ -408,7 +416,6 @@ FIXTURE_TEST_CASE ( VTableDropColumn_MetadataColumn_VDB_2735, WVDB_Fixture )
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
     }
-    REQUIRE_RC ( VDatabaseRelease ( db ) );
 }
 
 FIXTURE_TEST_CASE ( VCursor_FindNextRowIdDirect, WVDB_Fixture )
@@ -422,22 +429,10 @@ FIXTURE_TEST_CASE ( VCursor_FindNextRowIdDirect, WVDB_Fixture )
     const char* TableName = "TABLE1";
     const char* ColumnName = "column1";
 
+    MakeDatabase ( schemaText, "root_database" );
     {
-        VDatabase* db;
-        VSchema* schema;
-        REQUIRE_RC ( VDBManagerMakeSchema ( m_mgr, & schema ) );
-        REQUIRE_RC ( VSchemaParseText ( schema, NULL, schemaText . c_str (), schemaText . size () ) );
-
-        REQUIRE_RC ( VDBManagerCreateDB ( m_mgr,
-                                          & db,
-                                          schema,
-                                          "root_database",
-                                          kcmInit + kcmMD5,
-                                          "%s",
-                                          m_databaseName . c_str () ) );
-
         VTable* table;
-        REQUIRE_RC ( VDatabaseCreateTable ( db , & table, TableName, kcmInit + kcmMD5, TableName ) );
+        REQUIRE_RC ( VDatabaseCreateTable ( m_db , & table, TableName, kcmInit + kcmMD5, TableName ) );
 
         VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorWrite ( table, & cursor, kcmInsert ) );
@@ -461,15 +456,16 @@ FIXTURE_TEST_CASE ( VCursor_FindNextRowIdDirect, WVDB_Fixture )
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableReindex ( table ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VSchemaRelease ( schema ) );
-        REQUIRE_RC ( VDatabaseRelease ( db ) );
     }
+    REQUIRE_RC ( VDatabaseRelease ( m_db ) );
+
     {   // reopen
-        const VDatabase* db;
-        VDBManagerOpenDBRead ( m_mgr, & db, NULL, m_databaseName . c_str () );
+        VDBManager * mgr;
+        REQUIRE_RC ( VDBManagerMakeUpdate ( & mgr, NULL ) );
+        VDBManagerOpenDBRead ( mgr, (const VDatabase**)& m_db, NULL, m_databaseName . c_str () );
 
         const VTable* table;
-        REQUIRE_RC ( VDatabaseOpenTableRead ( db , & table, TableName ) );
+        REQUIRE_RC ( VDatabaseOpenTableRead ( m_db , & table, TableName ) );
 
         const VCursor* cursor;
         REQUIRE_RC ( VTableCreateCursorRead ( table, & cursor ) );
@@ -486,7 +482,6 @@ FIXTURE_TEST_CASE ( VCursor_FindNextRowIdDirect, WVDB_Fixture )
 
         REQUIRE_RC ( VCursorRelease ( cursor ) );
         REQUIRE_RC ( VTableRelease ( table ) );
-        REQUIRE_RC ( VDatabaseRelease ( db ) );
     }
 
 }
